@@ -1,3 +1,4 @@
+import builtins
 import datetime
 from files_sdk.api import Api
 from files_sdk.list_obj import ListObj
@@ -23,10 +24,14 @@ class Bundle:
         'username': None,     # string - Bundle creator username
         'clickwrap_id': None,     # int64 - ID of the clickwrap to use with this bundle.
         'inbox_id': None,     # int64 - ID of the associated inbox, if available.
+        'watermark_attachment': None,     # Preview watermark image applied to all bundle items.
+        'watermark_value': None,     # object - Preview watermark settings applied to all bundle items. Uses the same keys as Behavior.value
         'has_inbox': None,     # boolean - Does this bundle have an associated inbox?
         'paths': None,     # array - A list of paths in this bundle
         'password': None,     # string - Password for this bundle.
         'form_field_set_id': None,     # int64 - Id of Form Field Set to use with this bundle
+        'watermark_attachment_file': None,     # file - Preview watermark image applied to all bundle items.
+        'watermark_attachment_delete': None,     # boolean - If true, will delete the file stored in watermark_attachment
     }
 
     def __init__(self, attributes=None, options=None):
@@ -62,11 +67,11 @@ class Bundle:
             raise MissingParameterError("Parameter missing: id")
         if "id" in params and not isinstance(params["id"], int):
             raise InvalidParameterError("Bad parameter: id must be an int")
-        if "to" in params and not isinstance(params["to"], list):
+        if "to" in params and not isinstance(params["to"], builtins.list):
             raise InvalidParameterError("Bad parameter: to must be an list")
         if "note" in params and not isinstance(params["note"], str):
             raise InvalidParameterError("Bad parameter: note must be an str")
-        if "recipients" in params and not isinstance(params["recipients"], list):
+        if "recipients" in params and not isinstance(params["recipients"], builtins.list):
             raise InvalidParameterError("Bad parameter: recipients must be an list")
         response, _options = Api.send_request("POST", "/bundles/{id}/share".format(id=params['id']), params, self.options)
         return response.data
@@ -85,6 +90,8 @@ class Bundle:
     #   preview_only - boolean - Restrict users to previewing files only?
     #   require_registration - boolean - Show a registration page that captures the downloader's name and email address?
     #   require_share_recipient - boolean - Only allow access to recipients who have explicitly received the share via an email sent through the Files.com UI?
+    #   watermark_attachment_delete - boolean - If true, will delete the file stored in watermark_attachment
+    #   watermark_attachment_file - file - Preview watermark image applied to all bundle items.
     def update(self, params = None):
         if not isinstance(params, dict):
             params = {}
@@ -97,7 +104,7 @@ class Bundle:
             raise MissingParameterError("Parameter missing: id")
         if "id" in params and not isinstance(params["id"], int):
             raise InvalidParameterError("Bad parameter: id must be an int")
-        if "paths" in params and not isinstance(params["paths"], list):
+        if "paths" in params and not isinstance(params["paths"], builtins.list):
             raise InvalidParameterError("Bad parameter: paths must be an list")
         if "password" in params and not isinstance(params["password"], str):
             raise InvalidParameterError("Bad parameter: password must be an str")
@@ -147,15 +154,15 @@ class Bundle:
 
 # Parameters:
 #   user_id - int64 - User ID.  Provide a value of `0` to operate the current session's user.
-#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via either the X-Files-Cursor-Next header or the X-Files-Cursor-Prev header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 #   sort_by - object - If set, sort records by the specified field in either 'asc' or 'desc' direction (e.g. sort_by[last_login_at]=desc). Valid fields are `created_at` and `code`.
-#   filter - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `created_at`.
-#   filter_gt - object - If set, return records where the specifiied field is greater than the supplied value. Valid fields are `created_at`.
-#   filter_gteq - object - If set, return records where the specifiied field is greater than or equal to the supplied value. Valid fields are `created_at`.
-#   filter_like - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `created_at`.
-#   filter_lt - object - If set, return records where the specifiied field is less than the supplied value. Valid fields are `created_at`.
-#   filter_lteq - object - If set, return records where the specifiied field is less than or equal to the supplied value. Valid fields are `created_at`.
+#   filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `created_at`.
+#   filter_gt - object - If set, return records where the specified field is greater than the supplied value. Valid fields are `created_at`.
+#   filter_gteq - object - If set, return records where the specified field is greater than or equal to the supplied value. Valid fields are `created_at`.
+#   filter_like - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `created_at`.
+#   filter_lt - object - If set, return records where the specified field is less than the supplied value. Valid fields are `created_at`.
+#   filter_lteq - object - If set, return records where the specified field is less than or equal to the supplied value. Valid fields are `created_at`.
 def list(params = None, options = None):
     if not isinstance(params, dict):
         params = {}
@@ -219,6 +226,7 @@ def get(id, params = None, options = None):
 #   clickwrap_id - int64 - ID of the clickwrap to use with this bundle.
 #   inbox_id - int64 - ID of the associated inbox, if available.
 #   require_share_recipient - boolean - Only allow access to recipients who have explicitly received the share via an email sent through the Files.com UI?
+#   watermark_attachment_file - file - Preview watermark image applied to all bundle items.
 def create(params = None, options = None):
     if not isinstance(params, dict):
         params = {}
@@ -226,7 +234,7 @@ def create(params = None, options = None):
         options = {}
     if "user_id" in params and not isinstance(params["user_id"], int):
         raise InvalidParameterError("Bad parameter: user_id must be an int")
-    if "paths" in params and not isinstance(params["paths"], list):
+    if "paths" in params and not isinstance(params["paths"], builtins.list):
         raise InvalidParameterError("Bad parameter: paths must be an list")
     if "password" in params and not isinstance(params["password"], str):
         raise InvalidParameterError("Bad parameter: password must be an str")
@@ -265,11 +273,11 @@ def share(id, params = None, options = None):
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
-    if "to" in params and not isinstance(params["to"], list):
+    if "to" in params and not isinstance(params["to"], builtins.list):
         raise InvalidParameterError("Bad parameter: to must be an list")
     if "note" in params and not isinstance(params["note"], str):
         raise InvalidParameterError("Bad parameter: note must be an str")
-    if "recipients" in params and not isinstance(params["recipients"], list):
+    if "recipients" in params and not isinstance(params["recipients"], builtins.list):
         raise InvalidParameterError("Bad parameter: recipients must be an list")
     if "id" not in params:
         raise MissingParameterError("Parameter missing: id")
@@ -290,6 +298,8 @@ def share(id, params = None, options = None):
 #   preview_only - boolean - Restrict users to previewing files only?
 #   require_registration - boolean - Show a registration page that captures the downloader's name and email address?
 #   require_share_recipient - boolean - Only allow access to recipients who have explicitly received the share via an email sent through the Files.com UI?
+#   watermark_attachment_delete - boolean - If true, will delete the file stored in watermark_attachment
+#   watermark_attachment_file - file - Preview watermark image applied to all bundle items.
 def update(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
@@ -298,7 +308,7 @@ def update(id, params = None, options = None):
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
-    if "paths" in params and not isinstance(params["paths"], list):
+    if "paths" in params and not isinstance(params["paths"], builtins.list):
         raise InvalidParameterError("Bad parameter: paths must be an list")
     if "password" in params and not isinstance(params["password"], str):
         raise InvalidParameterError("Bad parameter: password must be an str")
