@@ -8,7 +8,14 @@ class UsageDailySnapshot:
     default_attributes = {
         'id': None,     # int64 - ID of the usage record
         'date': None,     # date - The date of this usage record
-        'current_storage': None,     # int64 - The quantity of storage held for this site
+        'api_usage_available': None,     # boolean - True if the API usage fields `read_api_usage` and `write_api_usage` can be relied upon.  If this is false, we suggest hiding that value from any UI.
+        'read_api_usage': None,     # int64 - Read API Calls used on this day. Note: only updated for days before the current day.
+        'write_api_usage': None,     # int64 - Write API Calls used on this day. Note: only updated for days before the current day.
+        'user_count': None,     # int64 - Number of billable users as of this day.
+        'current_storage': None,     # int64 - GB of Files Native Storage used on this day.
+        'deleted_files_storage': None,     # int64 - GB of Files Native Storage used on this day for files that have been deleted and are stored as backups.
+        'deleted_files_counted_in_minimum': None,     # int64 - GB of Files Native Storage used on this day for files that have been permanently deleted but were uploaded less than 30 days ago, and are still billable.
+        'root_storage': None,     # int64 - GB of Files Native Storage used for the root folder.  Included here because this value will not be part of `usage_by_top_level_dir`
         'usage_by_top_level_dir': None,     # array - Usage broken down by each top-level folder
     }
 
